@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Command';
 
 use Mojo::Server::FastCGI;
 
-our $VERSION = '0.3';
+our $VERSION = '0.4';
 
 has description => <<'EOF';
 Start application with FastCGI.
@@ -13,7 +13,7 @@ usage: $0 fastcgi
 EOF
 
 # "Interesting... Oh no wait, the other thing, tedious."
-sub run { Mojo::Server::FastCGI->new->run }
+sub run { Mojo::Server::FastCGI->new(app => shift->app)->run }
 
 1;
 __END__
